SocialCrawler
=============

It is a python package to help get data from Twitter, Foursquare.

This package was created to facilitate the data mining from Twitter and
Foursquare.

Install (generic way)
---------------------

.. code:: python

        $ python3.4 -m pip install SocialCrawler

How work ?
----------

Requeriments
^^^^^^^^^^^^

-  Python >= 3.4 
-  Foursquare developer credentials ( if you wanna work with)
-  Twitter developer credentials ( if you wanna work with )
-  Facebook developer credentials (Optional)

Get example from .. _Repository: https://github.com/JosielWirlino/SocialCrawler/